@@ -1,6 +1,6 @@
 'use strict'
 
-const { test, skip } = require('node:test')
+const { test } = require('node:test')
 const { notEqual, strictEqual, deepStrictEqual } = require('node:assert')
 const { rm } = require('node:fs/promises')
 const { cacheStoreTests, writeBody, compareGetResults } = require('./cache-store-test-utils.js')
@@ -8,24 +8,17 @@ const { cacheStoreTests, writeBody, compareGetResults } = require('./cache-store
 let hasSqlite = false
 try {
   require('node:sqlite')
-
-  const SqliteCacheStore = require('../../lib/cache/sqlite-cache-store.js')
-  cacheStoreTests(SqliteCacheStore)
   hasSqlite = true
 } catch (err) {
-  if (err.code === 'ERR_UNKNOWN_BUILTIN_MODULE') {
-    skip('`node:sqlite` not present')
-  } else {
+  if (err.code !== 'ERR_UNKNOWN_BUILTIN_MODULE') {
     throw err
   }
 }
 
-test('SqliteCacheStore works nicely with multiple stores', async (t) => {
-  if (!hasSqlite) {
-    t.skip()
-    return
-  }
+const SqliteCacheStore = require('../../lib/cache/sqlite-cache-store.js')
+cacheStoreTests(SqliteCacheStore, { skip: !hasSqlite })
 
+test('SqliteCacheStore works nicely with multiple stores', { skip: !hasSqlite }, async (t) => {
   const SqliteCacheStore = require('../../lib/cache/sqlite-cache-store.js')
   const sqliteLocation = 'cache-interceptor.sqlite'
 
@@ -88,12 +81,7 @@ test('SqliteCacheStore works nicely with multiple stores', async (t) => {
   }
 })
 
-test('SqliteCacheStore maxEntries', async (t) => {
-  if (!hasSqlite) {
-    t.skip()
-    return
-  }
-
+test('SqliteCacheStore maxEntries', { skip: !hasSqlite }, async () => {
   const SqliteCacheStore = require('../../lib/cache/sqlite-cache-store.js')
 
   const store = new SqliteCacheStore({
@@ -133,12 +121,7 @@ test('SqliteCacheStore maxEntries', async (t) => {
   strictEqual(store.size <= 11, true)
 })
 
-test('SqliteCacheStore two writes', async (t) => {
-  if (!hasSqlite) {
-    t.skip()
-    return
-  }
-
+test('SqliteCacheStore two writes', { skip: !hasSqlite }, async () => {
   const SqliteCacheStore = require('../../lib/cache/sqlite-cache-store.js')
 
   const store = new SqliteCacheStore({
@@ -182,12 +165,7 @@ test('SqliteCacheStore two writes', async (t) => {
   }
 })
 
-test('SqliteCacheStore write & read', async (t) => {
-  if (!hasSqlite) {
-    t.skip()
-    return
-  }
-
+test('SqliteCacheStore write & read', { skip: !hasSqlite }, async () => {
   const SqliteCacheStore = require('../../lib/cache/sqlite-cache-store.js')
 
   const store = new SqliteCacheStore({
