@@ -4,7 +4,7 @@ const { tspl } = require('@matteo.collina/tspl')
 const { test, after, mock } = require('node:test')
 const { Client } = require('..')
 const { createServer } = require('node:https')
-const pem = require('https-pem')
+const pem = require('@metcoder95/https-pem')
 const tls = require('node:tls')
 
 test('custom session passed to client will be used in tls connect call', async (t) => {
@@ -12,7 +12,7 @@ test('custom session passed to client will be used in tls connect call', async (
 
   const mockConnect = mock.method(tls, 'connect')
 
-  const server = createServer(pem, (req, res) => {
+  const server = createServer({ ...pem, joinDuplicateHeaders: true }, (req, res) => {
     t.strictEqual('/', req.url)
     t.strictEqual('GET', req.method)
     res.setHeader('content-type', 'text/plain')
