@@ -1,7 +1,7 @@
 'use strict'
 
 const assert = require('node:assert')
-const events = require('node:events')
+const { once } = require('node:events')
 const http = require('node:http')
 const { test, describe } = require('node:test')
 const { EventSource } = require('../../lib/web/eventsource/eventsource')
@@ -11,8 +11,7 @@ describe('EventSource - eventhandler idl', async () => {
     res.writeHead(200, 'dummy')
   })
 
-  server.listen(0)
-  await events.once(server, 'listening')
+  await once(server.listen(0), 'listening')
   const port = server.address().port
 
   let done = 0
