@@ -4,13 +4,12 @@ const { test } = require('node:test')
 const assert = require('node:assert')
 const { createServer } = require('node:http')
 const { once } = require('node:events')
-const { Blob } = require('node:buffer')
 const { fetch, FormData } = require('../..')
 const { closeServerAsPromise } = require('../utils/node-http')
 
 // https://github.com/nodejs/undici/issues/1783
 test('Content-Length is set when using a FormData body with fetch', async (t) => {
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     // TODO: check the length's value once the boundary has a fixed length
     assert.ok('content-length' in req.headers) // request has content-length header
     assert.ok(!Number.isNaN(Number(req.headers['content-length'])))
