@@ -10,7 +10,7 @@ const { closeServerAsPromise } = require('../utils/node-http')
 test('Headers retain keys case-sensitive', async (t) => {
   const assert = tspl(t, { plan: 4 })
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     assert.ok(req.rawHeaders.includes('Content-Type'))
 
     res.end()
