@@ -10,7 +10,7 @@ const { fetch, setGlobalDispatcher, Agent } = require('../..')
 const { once } = require('node:events')
 const { closeServerAsPromise } = require('../utils/node-http')
 
-const supportedHashes = getHashes()
+const supportedHashAlgorithms = getHashes()
 
 setGlobalDispatcher(new Agent({
   keepAliveTimeout: 1,
@@ -21,7 +21,7 @@ test('request with correct integrity checksum', (t, done) => {
   const body = 'Hello world!'
   const hash = createHash('sha256').update(body).digest('base64')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -40,7 +40,7 @@ test('request with wrong integrity checksum', async (t) => {
   const body = 'Hello world!'
   const hash = 'c0535e4be2b79ffd93291305436bf889314e4a3faec05ecffcbb7df31ad9e51b'
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   }).listen(0)
 
@@ -60,7 +60,7 @@ test('request with integrity checksum on encoded body', (t, done) => {
   const body = 'Hello world!'
   const hash = createHash('sha256').update(body).digest('base64')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.setHeader('content-encoding', 'gzip')
     res.end(gzipSync(body))
   })
@@ -77,7 +77,7 @@ test('request with integrity checksum on encoded body', (t, done) => {
 })
 
 test('request with a totally incorrect integrity', async (t) => {
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end()
   }).listen(0)
 
@@ -93,7 +93,7 @@ test('request with mixed in/valid integrities', async (t) => {
   const body = 'Hello world!'
   const hash = createHash('sha256').update(body).digest('base64')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   }).listen(0)
 
@@ -105,11 +105,11 @@ test('request with mixed in/valid integrities', async (t) => {
   }))
 })
 
-test('request with sha384 hash', { skip: !supportedHashes.includes('sha384') }, async (t) => {
+test('request with sha384 hash', { skip: !supportedHashAlgorithms.includes('sha384') }, async (t) => {
   const body = 'Hello world!'
   const hash = createHash('sha384').update(body).digest('base64')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   }).listen(0)
 
@@ -127,11 +127,11 @@ test('request with sha384 hash', { skip: !supportedHashes.includes('sha384') },
   }))
 })
 
-test('request with sha512 hash', { skip: !supportedHashes.includes('sha512') }, async (t) => {
+test('request with sha512 hash', { skip: !supportedHashAlgorithms.includes('sha512') }, async (t) => {
   const body = 'Hello world!'
   const hash = createHash('sha512').update(body).digest('base64')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   }).listen(0)
 
@@ -149,12 +149,29 @@ test('request with sha512 hash', { skip: !supportedHashes.includes('sha512') },
   }))
 })
 
+test('request with sha512 hash', { skip: !supportedHashAlgorithms.includes('sha512') || !supportedHashAlgorithms.includes('sha384') }, async (t) => {
+  const body = 'Hello world!'
+  const hash384 = createHash('sha384').update(body).digest('base64')
+
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
+    res.end(body)
+  }).listen(0)
+
+  t.after(closeServerAsPromise(server))
+  await once(server, 'listening')
+
+  // request should fail
+  await assert.rejects(fetch(`http://localhost:${server.address().port}`, {
+    integrity: `sha512-${hash384} sha384-${hash384}`
+  }))
+})
+
 test('request with correct integrity checksum (base64url)', async (t) => {
   t = tspl(t, { plan: 1 })
   const body = 'Hello world!'
   const hash = createHash('sha256').update(body).digest('base64url')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -176,7 +193,7 @@ test('request with incorrect integrity checksum (base64url)', async (t) => {
   const body = 'Hello world!'
   const hash = createHash('sha256').update('invalid').digest('base64url')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -196,7 +213,7 @@ test('request with incorrect integrity checksum (only dash)', async (t) => {
 
   const body = 'Hello world!'
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -216,7 +233,7 @@ test('request with incorrect integrity checksum (non-ascii character)', async (t
 
   const body = 'Hello world!'
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -238,7 +255,7 @@ test('request with incorrect stronger integrity checksum (non-ascii character)',
   const sha256 = createHash('sha256').update(body).digest('base64')
   const sha384 = 'ä'
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -263,7 +280,7 @@ test('request with correct integrity checksum (base64). mixed', async (t) => {
   const sha384 = createHash('sha384').update(body).digest('base64')
   const sha512 = createHash('sha512').update(body).digest('base64')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
@@ -309,7 +326,7 @@ test('request with correct integrity checksum (base64url). mixed', async (t) =>
   const sha384 = createHash('sha384').update(body).digest('base64url')
   const sha512 = createHash('sha512').update(body).digest('base64url')
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.end(body)
   })
 
