@@ -10,7 +10,7 @@ const { once } = require('node:events')
 test('ignore informational response', async (t) => {
   t = tspl(t, { plan: 2 })
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.writeProcessing()
     req.pipe(res)
   })
@@ -42,7 +42,7 @@ test('ignore informational response', async (t) => {
 test('error 103 body', async (t) => {
   t = tspl(t, { plan: 2 })
 
-  const server = net.createServer((socket) => {
+  const server = net.createServer({ joinDuplicateHeaders: true }, (socket) => {
     socket.write('HTTP/1.1 103 Early Hints\r\n')
     socket.write('Content-Length: 1\r\n')
     socket.write('\r\n')
@@ -71,7 +71,7 @@ test('error 103 body', async (t) => {
 test('error 100 body', async (t) => {
   t = tspl(t, { plan: 2 })
 
-  const server = net.createServer((socket) => {
+  const server = net.createServer({ joinDuplicateHeaders: true }, (socket) => {
     socket.write('HTTP/1.1 100 Early Hints\r\n')
     socket.write('\r\n')
   })
@@ -97,7 +97,7 @@ test('error 100 body', async (t) => {
 test('error 101 upgrade', async (t) => {
   t = tspl(t, { plan: 2 })
 
-  const server = net.createServer((socket) => {
+  const server = net.createServer({ joinDuplicateHeaders: true }, (socket) => {
     socket.write('HTTP/1.1 101 Switching Protocols\r\nUpgrade: example/1\r\nConnection: Upgrade\r\n')
     socket.write('\r\n')
   })
@@ -123,7 +123,7 @@ test('error 101 upgrade', async (t) => {
 test('1xx response without timeouts', async t => {
   t = tspl(t, { plan: 2 })
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     res.writeProcessing()
     setTimeout(() => req.pipe(res), 2000)
   })
