@@ -9,7 +9,7 @@ const { tspl } = require('@matteo.collina/tspl')
 test('redirecting works with a FormData body', async (t) => {
   const plan = tspl(t, { plan: 1 })
 
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     if (req.url === '/1') {
       res.writeHead(302, undefined, { location: '/2' })
       res.end()
@@ -29,8 +29,7 @@ test('redirecting works with a FormData body', async (t) => {
   const { context } = await request(`http://localhost:${server.address().port}/1`, {
     body,
     method: 'POST',
-    dispatcher: agent,
-    maxRedirections: 1
+    dispatcher: agent
   })
 
   plan.deepStrictEqual(context.history, [
