@@ -5,7 +5,7 @@ const { createServer } = require('node:http')
 /* global test, expect */
 
 test('should work in jest', async () => {
-  const server = createServer((req, res) => {
+  const server = createServer({ joinDuplicateHeaders: true }, (req, res) => {
     expect(req.url).toBe('/')
     expect(req.method).toBe('POST')
     expect(req.headers.host).toBe(`localhost:${server.address().port}`)
