@@ -1,10 +1,9 @@
-import {expectAssignable} from 'tsd'
+import { expectAssignable } from 'tsd'
 import { Client, buildConnector } from '../..'
-import {ConnectionOptions, TLSSocket} from 'tls'
-import {Socket} from 'net'
-import {IpcNetConnectOpts, NetConnectOpts, TcpNetConnectOpts} from "net";
+import { TLSSocket } from 'tls'
+import { Socket } from 'net'
 
-const connector = buildConnector({ rejectUnauthorized: false })
+const connector = buildConnector({ rejectUnauthorized: false, allowH2: false })
 expectAssignable<Client>(new Client('', {
   connect (opts: buildConnector.Options, cb: buildConnector.Callback) {
     connector(opts, (...args) => {
@@ -25,12 +24,14 @@ expectAssignable<Client>(new Client('', {
 expectAssignable<buildConnector.BuildOptions>({
   checkServerIdentity: () => undefined, // Test if ConnectionOptions is assignable
   localPort: 1234, // Test if TcpNetConnectOpts is assignable
-});
+  keepAlive: true,
+  keepAliveInitialDelay: 12345
+})
 
 expectAssignable<buildConnector.Options>({
-  protocol: "http",
-  hostname: "example.com",
-  port: "",
-  localAddress: "127.0.0.1",
-  httpSocket: new Socket(),
-});
+  protocol: 'http',
+  hostname: 'example.com',
+  port: '',
+  localAddress: '127.0.0.1',
+  httpSocket: new Socket()
+})
