@@ -1,6 +1,6 @@
 import { expectAssignable } from 'tsd'
 import { URL } from 'url'
-import { ProxyAgent, setGlobalDispatcher, getGlobalDispatcher, Agent } from '../..'
+import { ProxyAgent, setGlobalDispatcher, getGlobalDispatcher, Agent, Pool } from '../..'
 
 expectAssignable<ProxyAgent>(new ProxyAgent(''))
 expectAssignable<ProxyAgent>(new ProxyAgent({ uri: '' }))
@@ -10,20 +10,22 @@ expectAssignable<ProxyAgent>(
     uri: '',
     auth: '',
     token: '',
-    maxRedirections: 1,
     factory: (_origin: URL, opts: Object) => new Agent(opts),
     requestTls: {
       ca: [''],
       key: '',
       cert: '',
-      servername: ''
+      servername: '',
+      timeout: 1
     },
     proxyTls: {
       ca: [''],
       key: '',
       cert: '',
-      servername: ''
-    }
+      servername: '',
+      timeout: 1
+    },
+    clientFactory: (origin: URL, opts: object) => new Pool(origin, opts)
   })
 )
 
